#include "Vector2.h"

Vector2::Vector2(float x, float y) {
	this->x = x;
	this->y = y;
}

Vector2 Vector2::operator+(const Vector2& v) const{
	return Vector2(x + v.x, y + v.y);
}

Vector2 Vector2::operator-(const Vector2& v) const{
	return Vector2(x - v.x, y - v.y);
}

Vector2 Vector2::operator*(const float& f) const{
	return Vector2(x*f, y*f);
}

Vector2 Vector2::operator*(const Vector2& v) const{
	return Vector2(x*v.x, y*v.y);
}

Vector2 Vector2::operator/(const float& f) const{
	if (x != 0.0f) {
		return Vector2(x/f, y/f);
	}
	else {
		return Vector2(0.0F, 0.0F);
	}
}

float Vector2Cross(Vector2* v1, Vector2* v2) {
	return v1->x * v2->y - v1->y * v2->x;
}

Vector2& Vector2::operator =(const Vector2& v) {
	x = v.x;
	y = v.y;
	return *this;
}

Vector2& Vector2::operator +=(const Vector2& v)
{
	x += v.x;
	y += v.y;
	return *this;
}

Vector2& Vector2::operator -=(const Vector2& v)
{
	x -= v.x;
	y -= v.y;
	return *this;
}

Vector2& Vector2::operator *=(const float& a)
{
	return Vector2(x * a, y * a);
}

Vector2& Vector2::operator /=(const float& a) {
	return Vector2(x / a, y / a);
}

bool Vector2::operator ==(const Vector2& v) const{
	return (v.x == x) && (v.y == y);
}

bool Vector2::operator !=(const Vector2& v) const{
	return (v.x != x) && (v.y != y);
}